@extends('layouts.app')

@section('content')

<h1 class="text-center">{{ $label }}</h1>
<div style="width: 100%; height: 800px" id="svg-container">
</div>

<script src="https://cdnjs.cloudflare.com/ajax/libs/d3/7.1.1/d3.min.js"
integrity="sha512-COTaPOlz12cG4fSfcBsxZsjauBAyldqp+8FQUM/dZHm+ts/jR4AFoJhCqxy8K10Jrf3pojfsbq7fAPTb1XaVkg=="
crossorigin="anonymous" referrerpolicy="no-referrer"></script>
<script>
    var url = "/app/ranking/{{ $label }}/json";
    var container = document.getElementById("svg-container");
    var svg = d3.select(container).append("svg");

    d3.json(url).then(data => {
        data = data.slice(0, 100);

        var colors = d3.scaleLinear().domain([0, 1]).range(["blue", "orange"]);
        var width = container.clientWidth;
        var height = container.clientHeight;

        svg.attr("width", width);
        svg.attr("height", height);
        console.log(width);

        svg.attr("font-size", 11)
            .attr("font-family", "sans-serif")
            .attr("text-anchor", "middle");


        pack = data => d3.pack()
            .size([width - 2, height - 2])
            .padding(3)
          (d3.hierarchy({children: data})
            .sum(d => d.score))

        const root = pack(data);
        const leaf = svg.selectAll("g")
            .data(root.leaves())
            .join("g")
            .attr("transform", d => `translate(${d.x + 1},${d.y + 1})`);

        leaf.append("circle")
            .attr("id", d => (d.leafUid = d.data.id))
            .attr("r", d => d.r)
            .attr("fill-opacity", 0.7)
            .attr("fill", d => colors(d.data.score));

        leaf.append("clipPath")
            .attr("id", d => (d.clipUid = "clip-" + d.data.id))
            .append("use")
            .attr("xlink:href", d => d.leafUid.href);

        leaf.append("text")
            .attr("clip-path", d => d.clipUid)
            .selectAll("tspan")
            .data(d => d.data.subject.name.split(/(?=[A-Z][a-z])|\s+/g))
            .join("tspan")
                .attr("x", 0)
                .attr("y", (d, i, nodes) => `${i - nodes.length / 2 + 0.8}em`)
                .text(d => d);

        leaf.append("title")
            .text(d => d.score);
    });

</script>
@endsection